@@ -25,6 +25,7 @@ configuration = CustomConfig("sequana", verbose=False)
 sequana_config_path = configuration.user_config_dir
 
 # This must be import before all other modules (sequana_data function)
+from .codon import Codon
 from .datatools import sequana_data
 from .assembly import *
 from .bamtools import BAM, SAMFlags, SAM, CRAM
@@ -51,7 +52,9 @@ from .enrichment.kegg import KEGGPathwayEnrichment
 from .enrichment.panther import PantherEnrichment
 from .enrichment.gsea import GSEA
 
-
+from .idr import IDR
+from .homer import Homer
+from .macs3 import MACS3Reader, PeakConsensus
 from .pacbio import PacbioSubreads
 from .phred import Quality
 from .rnadiff import RNADiffResults
